@@ -18,7 +18,6 @@ from pandas.core.panel import Panel
 from pandas.core.frame import DataFrame
 from pandas.core.reshape import get_dummies
 from pandas.core.series import Series
-from pandas.core.sparse import SparsePanel
 from pandas.stats.ols import OLS, MovingOLS
 import pandas.stats.common as com
 import pandas.stats.math as math
@@ -39,7 +38,8 @@ class PanelOLS(OLS):
         import warnings
         warnings.warn("The pandas.stats.plm module is deprecated and will be "
                       "removed in a future version. We refer to external packages "
-                      "like statsmodels, see some examples here: http://statsmodels.sourceforge.net/stable/mixed_linear.html",
+                      "like statsmodels, see some examples here: "
+                      "http://www.statsmodels.org/stable/mixed_linear.html",
                       FutureWarning, stacklevel=4)
         self._x_orig = x
         self._y_orig = y
@@ -136,8 +136,7 @@ class PanelOLS(OLS):
             if isinstance(data, Panel):
                 data = data.copy()
 
-            if not isinstance(data, SparsePanel):
-                data, cat_mapping = self._convert_x(data)
+            data, cat_mapping = self._convert_x(data)
 
             if not isinstance(data, Panel):
                 data = Panel.from_dict(data, intersect=True)
@@ -743,7 +742,8 @@ class NonPooledPanelOLS(object):
         import warnings
         warnings.warn("The pandas.stats.plm module is deprecated and will be "
                       "removed in a future version. We refer to external packages "
-                      "like statsmodels, see some examples here: http://statsmodels.sourceforge.net/stable/mixed_linear.html",
+                      "like statsmodels, see some examples here: "
+                      "http://www.statsmodels.org/stable/mixed_linear.html",
                       FutureWarning, stacklevel=4)
 
         for attr in self.ATTRIBUTES:
